from .__version__ import (          # noqa
    __title__,
    __description__,
    __url__,
    __version__,
    __author__,
    __author_email__,
    __license__,
    __copyright__
)

from .async_unshortenit import AsyncUnshortenIt    # noqa
